<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class To_do extends CI_Controller {

    public function __construct() {
        parent::__construct();

        $this->load->database();
        $this->load->library('grocery_CRUD');
        $this->load->model('User_model', 'User');
        $this->load->model('Todo_model', 'Todo');
        $this->User->isLogged();
    }

    public function _gc_output($output = null) {
        $content['nocPage'] = 'grocerycrud';
        $content['dadosTemplate']['tpt_Nome'] = 'To-do';
        $content['dadosTemplate']['tpt_Descricao'] = 'Tarefas a serem cumpridas';
        $content['dados'] = $output;
        $content['userData'] = $this->session->all_userdata()['logged_in'];
        $this->load->view('template',$content);
    }

    public function index() {
        $session_data = $this->session->userdata('logged_in');
        try {
            $crud = new grocery_CRUD();
            $crud->set_theme('flatgrid');
            $crud->set_table('to_do');
            $crud->set_subject('To-do');
            $crud->columns('td_id','td_titulo','td_prioridade', 'td_datacriacao', 'td_datalimite', 'td_encarregado', 'td_status');
            $crud->display_as('td_id', '#');
            $crud->display_as('td_titulo', 'Título');
            $crud->display_as('td_descricao', 'Descrição');
            $crud->display_as('td_datalimite', 'Data limite');
            $crud->display_as('td_criador', 'Criado por');
            $crud->display_as('td_encarregado', 'Encarregado');
            $crud->display_as('td_prioridade', 'Nivel de Prioridade');
            $crud->display_as('td_datacriacao', 'Data Criação');
            $crud->display_as('td_status', 'Status');
            $crud->order_by('td_datalimite', 'desc');
            $crud->callback_before_insert(array($this,'tratarDados'));
            $crud->callback_column('td_encarregado',array($this,'_callback_usuario'));
            $crud->callback_column('td_datacriacao',array($this,'_callback_data'));
            $crud->callback_column('td_prioridade',array($this,'_callback_prioridade'));
            $crud->callback_column('td_status',array($this,'_callback_status'));
            $crud->unset_add_fields('td_status', 'td_datacriacao');
            $crud->unset_fields('td_id');
            $crud->unset_jquery();
            $crud->unset_print();
            $crud->unset_export();

            if($crud->getState() == 'add') {
                $crud->set_relation('td_encarregado', 'usuarios', 'nome');
                $crud->set_relation('td_prioridade', 'prioridades_to_do', 'pri_nome');
                if($session_data['usr_id'] != 1) {
                    $crud->field_type('td_criador', 'invisible');
                    $crud->field_type('td_datacriacao', 'invisible');
                    $crud->field_type('td_status', 'invisible');
                }
            }
            if ($crud->getState() == 'edit') {
                $crud->set_relation('td_status', 'status_to_do', 'sts_nome');
                if($session_data['usr_id'] != 1) {
                    $crud->field_type('td_titulo', 'invisible');
                    $crud->field_type('td_criador', 'invisible');
                    $crud->field_type('td_prioridade', 'invisible');
                    $crud->field_type('td_datacriacao', 'invisible');
                    $crud->field_type('td_datalimite', 'invisible');
                    $crud->field_type('td_encarregado', 'invisible');
                    $crud->required_fields('td_descricao', 'td_status');
                }
            }
            if($session_data['usr_id'] == 1) {
                $crud->set_relation('td_status', 'status_to_do', 'sts_nome');
                $crud->set_relation('td_encarregado', 'usuarios', 'nome');
                $crud->set_relation('td_criador', 'usuarios', 'nome');
                $crud->set_relation('td_prioridade', 'prioridades_to_do', 'pri_nome');
            }


            $output = $crud->render();

            $this->_gc_output($output);

        }catch(Exception $e){
            show_error($e->getMessage().' - '.$e->getTraceAsString());
        }
    }

    public function _callback_usuario($value, $row) {
        $value = $this->User->getUserNome($value);
        return $value;
    }

    public function _callback_status($value, $row) {
        $value = $this->Todo->getStatusName($value);
        return $value;
    }

    public function _callback_prioridade($value, $row) {
        $value = $this->Todo->getPrioridadeName($value);
        return $value;
    }

    function _callback_data($data) {
        $data = date("d/m/Y", strtotime($data));;
        return $data;
    }


    function tratarDados($post_array) {
        date_default_timezone_set('America/Sao_Paulo');
        $session_data = $this->session->userdata('logged_in');
        $post_array['td_criador'] = $session_data['usr_id'];
        $post_array['td_datacriacao'] = date('Y-m-d', time());
        $post_array['td_status'] = 1;
        return $post_array;
    }
}